%% Examples of how to prepare data for HFOApp
%

% A Matlab file must have the following fields for HFOApp to read:
% mat, srate, labels, start_clock, file

% time series, channel x sample
mat = randn( 3, 1000000);

% sampling rate, in Hz
srate = 1000;

% cell array of channel labels
labels = {'a'; 'b'; 'c'};

% clock time of the first sample
start_clock = datetime( '1999-01-01 11:01:01', 'InputFormat', 'yyyy-MM-dd HH:mm:ss');

% full-path-to-file
file = '~/Desktop/example_data.mat';

% Save the data as a matlab file
save( file, 'mat', 'srate', 'labels', 'start_clock', 'file', '-v7.3');


%% Organize events generated by automatic detectors

% % Two required fields: 'nbtrls' and 'evs'
% single trial data
nbtrls = 1;
evs = [];

bpfreq = [80, 250];

%# Events for channel 'b'
evs(1).label = 'b';

% first event
% start and end sample locations
evs(1).info{ 1, 1} = [20, 500];
% event type, {'gamma'; 'ripple'; 'fastripple'; 'ultrafast'; 'spike'};
evs(1).info{ 1, 2} = {'ripple'}; 
% average frequency
evs(1).info{ 1, 3}.AvgFreq = mean( bpfreq);
% scalar of the peak z score for some detection methods
evs(1).info{ 1, 3}.PeakZScore = 0;
% number of oscillatory cycles, scalar
evs(1).info{ 1, 3}.NoCycles = 0;
% 1 x 2 vector of bandpass frequency
evs(1).info{ 1, 3}.BPFreq = bpfreq;

% second event
evs(1).info{ 2, 1} = [1000, 2500];
evs(1).info{ 2, 2} = {'ripple', 'spike'};
evs(1).info{ 2, 3}.AvgFreq = mean( bpfreq);
evs(1).info{ 2, 3}.PeakZScore = 0;
evs(1).info{ 2, 3}.NoCycles = 0;
evs(1).info{ 2, 3}.BPFreq = [80, 250];


%# Events for channel 'c'
evs(2).label = 'c';

% first event
evs(2).info{ 1, 1} = [2000, 2600];
evs(2).info{ 1, 2} = {'ripple'};
evs(2).info{ 1, 3}.AvgFreq = mean( bpfreq);
evs(2).info{ 1, 3}.PeakZScore = 0;
evs(2).info{ 1, 3}.NoCycles = 0;
evs(2).info{ 1, 3}.BPFreq = bpfreq;

% second event
evs(2).info{ 2, 1} = [7000, 9550];
evs(2).info{ 2, 2} = {'ripple'};
evs(2).info{ 2, 3}.AvgFreq = mean( bpfreq);
evs(2).info{ 2, 3}.PeakZScore = 0;
evs(2).info{ 2, 3}.NoCycles = 0;
evs(2).info{ 2, 3}.BPFreq = bpfreq;

save( '~/Desktop/example_data_evs.mat', 'evs', 'nbtrls');
